/****************************************************************************
** Meta object code from reading C++ file 'kbbmainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kblackbox-17.12.3/kbbmainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kbbmainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KBBMainWindow_t {
    QByteArrayData data[16];
    char stringdata0[157];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KBBMainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KBBMainWindow_t qt_meta_stringdata_KBBMainWindow = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KBBMainWindow"
QT_MOC_LITERAL(1, 14, 12), // "levelChanged"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 10), // "setRunning"
QT_MOC_LITERAL(4, 39, 1), // "r"
QT_MOC_LITERAL(5, 41, 11), // "updateStats"
QT_MOC_LITERAL(6, 53, 4), // "done"
QT_MOC_LITERAL(7, 58, 7), // "newGame"
QT_MOC_LITERAL(8, 66, 5), // "pause"
QT_MOC_LITERAL(9, 72, 5), // "state"
QT_MOC_LITERAL(10, 78, 15), // "settingsChanged"
QT_MOC_LITERAL(11, 94, 14), // "settingsDialog"
QT_MOC_LITERAL(12, 109, 14), // "showHighscores"
QT_MOC_LITERAL(13, 124, 5), // "solve"
QT_MOC_LITERAL(14, 130, 12), // "startSandbox"
QT_MOC_LITERAL(15, 143, 13) // "startTutorial"

    },
    "KBBMainWindow\0levelChanged\0\0setRunning\0"
    "r\0updateStats\0done\0newGame\0pause\0state\0"
    "settingsChanged\0settingsDialog\0"
    "showHighscores\0solve\0startSandbox\0"
    "startTutorial"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KBBMainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x0a /* Public */,
       3,    1,   75,    2, 0x0a /* Public */,
       5,    0,   78,    2, 0x0a /* Public */,
       6,    0,   79,    2, 0x08 /* Private */,
       7,    0,   80,    2, 0x08 /* Private */,
       8,    1,   81,    2, 0x08 /* Private */,
      10,    0,   84,    2, 0x08 /* Private */,
      11,    0,   85,    2, 0x08 /* Private */,
      12,    0,   86,    2, 0x08 /* Private */,
      13,    0,   87,    2, 0x08 /* Private */,
      14,    0,   88,    2, 0x08 /* Private */,
      15,    0,   89,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KBBMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KBBMainWindow *_t = static_cast<KBBMainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->levelChanged(); break;
        case 1: _t->setRunning((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->updateStats(); break;
        case 3: _t->done(); break;
        case 4: _t->newGame(); break;
        case 5: _t->pause((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->settingsChanged(); break;
        case 7: _t->settingsDialog(); break;
        case 8: _t->showHighscores(); break;
        case 9: _t->solve(); break;
        case 10: _t->startSandbox(); break;
        case 11: _t->startTutorial(); break;
        default: ;
        }
    }
}

const QMetaObject KBBMainWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KBBMainWindow.data,
      qt_meta_data_KBBMainWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KBBMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KBBMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KBBMainWindow.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KBBMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
