// This file is generated by kconfig_compiler_kf5 from kblackbox.kcfg.
// All changes you do to this file will be lost.
#ifndef KBBPREFS_H
#define KBBPREFS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class KBBPrefs : public KConfigSkeleton
{
  public:

    static KBBPrefs *self();
    ~KBBPrefs();

    /**
      Set File of the current theme of the graphic elements. (SVGZ file with path and file extension)
    */
    static
    void setTheme( const QString & v )
    {
      if (!self()->isImmutable( QStringLiteral( "theme" ) ))
        self()->mTheme = v;
    }

    /**
      Get File of the current theme of the graphic elements. (SVGZ file with path and file extension)
    */
    static
    QString theme()
    {
      return self()->mTheme;
    }

    /**
      Set Number of balls for custom difficulty level
    */
    static
    void setBalls( int v )
    {
      if (!self()->isImmutable( QStringLiteral( "balls" ) ))
        self()->mBalls = v;
    }

    /**
      Get Number of balls for custom difficulty level
    */
    static
    int balls()
    {
      return self()->mBalls;
    }

    /**
      Set Number of columns of the board for custom difficulty level
    */
    static
    void setColumns( int v )
    {
      if (!self()->isImmutable( QStringLiteral( "columns" ) ))
        self()->mColumns = v;
    }

    /**
      Get Number of columns of the board for custom difficulty level
    */
    static
    int columns()
    {
      return self()->mColumns;
    }

    /**
      Set Number of rows of the board for custom difficuty level
    */
    static
    void setRows( int v )
    {
      if (!self()->isImmutable( QStringLiteral( "rows" ) ))
        self()->mRows = v;
    }

    /**
      Get Number of rows of the board for custom difficuty level
    */
    static
    int rows()
    {
      return self()->mRows;
    }

  protected:
    KBBPrefs();
    friend class KBBPrefsHelper;


    // KBlackBox Setup
    QString mTheme;
    int mBalls;
    int mColumns;
    int mRows;

  private:
};

#endif

